@@ -16,8 +16,8 @@ from _drgn import (
     _linux_helper_find_task as find_task,
     _linux_helper_pid_task as pid_task,
 )
-from drgn import NULL, Object, Program, cast, container_of
-from drgn.helpers.linux.idr import idr_find, idr_for_each
+from drgn import Object, Program, cast, container_of
+from drgn.helpers.linux.idr import idr_for_each
 from drgn.helpers.linux.list import hlist_for_each_entry
 
 __all__ = (
