@@ -56,16 +56,20 @@ enum drgn_debug_info_scn {
 	DRGN_SCN_DEBUG_TYPES,
 	DRGN_SCN_DEBUG_ABBREV,
 	DRGN_SCN_DEBUG_STR,
+	DRGN_SCN_DEBUG_STR_OFFSETS,
 	DRGN_SCN_DEBUG_LINE,
+	DRGN_SCN_DEBUG_LINE_STR,
 
 	DRGN_NUM_DEBUG_SCN_DATA_PRECACHE,
 
 	/* Sections whose data we should cache when it is first used. */
-	DRGN_SCN_DEBUG_FRAME = DRGN_NUM_DEBUG_SCN_DATA_PRECACHE,
+	DRGN_SCN_DEBUG_ADDR = DRGN_NUM_DEBUG_SCN_DATA_PRECACHE,
+	DRGN_SCN_DEBUG_FRAME,
 	DRGN_SCN_EH_FRAME,
 	DRGN_SCN_ORC_UNWIND_IP,
 	DRGN_SCN_ORC_UNWIND,
 	DRGN_SCN_DEBUG_LOC,
+	DRGN_SCN_DEBUG_LOCLISTS,
 
 	DRGN_NUM_DEBUG_SCN_DATA,
 
