@@ -36,7 +36,7 @@
 /** Minor version of drgn. */
 #define DRGN_VERSION_MINOR 0
 /** Patch level of drgn. */
-#define DRGN_VERSION_PATCH 13
+#define DRGN_VERSION_PATCH 14
 
 /**
  * @defgroup ErrorHandling Error handling
@@ -1403,6 +1403,15 @@ struct drgn_error *drgn_object_read_value(const struct drgn_object *obj,
 void drgn_object_deinit_value(const struct drgn_object *obj,
 			      const union drgn_value *value);
 
+/**
+ * Get the binary representation of the value of a @ref drgn_object.
+ *
+ * @param[out] Buffer to read into. Size must be at least
+ * `drgn_object_size(obj)`.
+ */
+struct drgn_error *drgn_object_read_bytes(const struct drgn_object *obj,
+					  void *buf);
+
 /**
  * Get the value of an object encoded with @ref
  * drgn_object_encoding::DRGN_OBJECT_ENCODING_SIGNED.
